@@ -30,9 +30,7 @@
 #include <Kdelibs4ConfigMigrator>
 #include <KAboutData>
 #include <KLocalizedString>
-#if defined HAVE_KCRASH
 #include <KCrash>
-#endif
 
 #include "floppy.h"
 
@@ -72,9 +70,7 @@ int main( int argc, char *argv[] )
     aboutData.setTranslator( i18nc( "NAME OF TRANSLATORS", "Your names" ), i18nc( "EMAIL OF TRANSLATORS", "Your emails" ) );
     KAboutData::setApplicationData(aboutData);
 
-#if defined HAVE_KCRASH
     KCrash::initialize();
-#endif
 
     QCommandLineParser parser;
     aboutData.setupCommandLine(&parser);
